// The original version of this code (revision 2 of the Subversion
// archive) was released subject to the following license:

//   Copyright (c) 2006, Sun Microsystems, Inc.  All rights reserved.
//   Redistribution and use in source and binary forms, with or
//   without modification, are permitted provided that the following
//   conditions are met:

//   * Redistributions of source code must retain the above copyright
//     notice, this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above
//     copyright notice, this list of conditions and the following
//     disclaimer in the documentation and/or other materials provided
//     with the distribution.
//   * Neither the name of Sun Microsystems or the names of
//     contributors may be used to endorse or promote products derived
//     from this software without specific prior written permission.
 
//   THIS SOFTWARE IS PROVIDED BY SUN AND ITS LICENSORS ``AS IS'' AND
//   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
//   THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
//   PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SUN OR ITS
//   LICENSORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
//   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
//   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
//   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
//   AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
//   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
//   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
//   POSSIBILITY OF SUCH DAMAGE.

// Subsequent additions and modifications are Copyright (c) 2006 David
// Carlton, and may be used subject to the same conditions.

// Private data shared between modules.

#ifndef UNITTEST_PRIVATE_H
#define UNITTEST_PRIVATE_H

#include <list>
#include <string>

namespace UnitTest {

  namespace Private {

    class FailureRequest {
    public:
      FailureRequest()
	: shouldFail_(false),
	  filename_(0), line_(0), function_(0) {
      }

      FailureRequest(const std::string &message, const char *filename,
		     int line, const char *function)
	: shouldFail_(true), message_(message),
	  filename_(filename), line_(line), function_(function) {
      }

      bool shouldFail() const { return shouldFail_; }
      std::string message() const { return message_; }
      const char *filename() const { return filename_; }
      int line() const { return line_; }
      const char *function() const { return function_; }

    private:
      bool shouldFail_;
      std::string message_;
      const char *filename_;
      int line_;
      const char *function_;
    };

    typedef std::list<FailureRequest> FailureList;
    extern FailureList failureRequests_;

    void printFailure(std::ostream &stream,
		      const char *filename, int line,
		      const std::string &message,
		      const std::string &testName, const char *function,
		      const std::string &trailer);

    class Debug {
    public:
      explicit Debug(bool newDebug)
	: old_(debug_) {
	debug_ = newDebug;
      }

      ~Debug() {
	debug_ = old_;
      }

      static bool debug() { return debug_; }

    private:
      static bool debug_;

      const bool old_;
    };

  }

}

#endif // UNITTEST_PRIVATE_H
